@@ -4,7 +4,7 @@
 use v5.12;
 
 package Graphics::Toolkit::Color;
-our $VERSION = '1.02';
+our $VERSION = '1.04';
 
 use Carp;
 use Graphics::Toolkit::Color::Constant ':all';
@@ -40,7 +40,10 @@ sub _new_from_scalar {
     } elsif (ref $arg eq 'ARRAY'){
         return carp "need exactly 3 RGB numbers!" unless @$arg == 3;
         $arg = { r => $arg->[0], g => $arg->[1], b => $arg->[2] };
+    } elsif (ref $arg eq __PACKAGE__) {
+        $arg = { r => $arg->[1], g => $arg->[2], b => $arg->[3] };
     }
+    
     return carp $new_help unless ref $arg eq 'HASH' and keys %$arg == 3;
     my %named_arg = map { _shrink_key($_) =>  $arg->{$_} } keys %$arg; # reduce keys to lc first char
 
@@ -284,23 +287,24 @@ Get a color by providing a name from the X11, HTML (CSS) or SVG standard
 or a Pantone report. UPPER or CamelCase will be normalized to lower case
 and inserted underscore letters ('_') will be ignored as perl does in
 numbers (1_000 == 1000). All available names are listed under
-L<Graphics::Toolkit::Color::Constant>.s
+L<Graphics::Toolkit::Color::Constant>.
 
     my $color = Graphics::Toolkit::Color->new('Emerald');
     my @names = Graphics::Toolkit::Color::Constant::all_names(); # select from these
 
-=head2 new( 'pallet:color' )
+=head2 new( 'scheme:color' )
 
-Get a color by name from a specific pallet or standard as provided by an
+Get a color by name from a specific scheme or standard as provided by an
 external module L<Graphics::ColorNames>::* , which has to be installed
 separately. * is a placeholder for the pallet name, which might be: 
 Crayola, CSS, EmergyC, GrayScale, HTML, IE, Mozilla, Netscape, Pantone,
 PantoneReport, SVG, VACCC, Werner, Windows, WWW or X. In ladder case
-Graphics::ColorNames::X has to be installed. The color name will be 
-normalized as above.
+Graphics::ColorNames::X has to be installed. You can get them all at once
+via L<Bundle::Graphics::ColorNames>. The color name will be  normalized
+as above.
 
     my $color = Graphics::Toolkit::Color->new('SVG:green');
-    my @s = Graphics::ColorNames::all_schemes();    # installed pallets
+    my @s = Graphics::ColorNames::all_schemes();          # installed
 
 =head2 new( '#rgb' )
 
@@ -308,7 +312,7 @@ Color definitions in hexadecimal format as widely used in the web, are
 also acceptable.
 
     my $color = Graphics::Toolkit::Color->new('#FF0000');
-    my $color = Graphics::Toolkit::Color->new('#f00');   # works too
+    my $color = Graphics::Toolkit::Color->new('#f00');    # works too
 
 
 =head2 new( [$r, $g, $b] )
@@ -329,7 +333,7 @@ the first letter of each key is significant.
 
     my $red = Graphics::Toolkit::Color->new( r => 255, g => 0, b => 0 );
     my $red = Graphics::Toolkit::Color->new({r => 255, g => 0, b => 0}); # works too
-    ... Color->new( Red => 255, Green => 0, Blue => 0);      # also fine
+    ... Color->new( Red => 255, Green => 0, Blue => 0);   # also fine
 
 =head2 new( {h => $h, s => $s, l => $l} )
 
@@ -551,6 +555,10 @@ L<Graphics::ColorObject>
 
 =item *
 
+L<Color::Calc>
+
+=item *
+
 L<Convert::Color>
 
 =item *
